# Code used in simulations for Northrup et al. 

# Example for one deer and 3 covariates provided as used.file.R and avail.file.R

# Load needed libraries

library(arm)

# Read in data


used.file<-file.choose()

avail.file<-file.choose()

load(used.file)

load(avail.file)

# 30 000 available locations, 1 000 iterations

n.iter=100
 
beta.0.30<-rep(0,n.iter)
beta.1.30<-rep(0,n.iter)
beta.2.30<-rep(0,n.iter)
beta.3.30<-rep(0,n.iter)
 
 
for(i in 1:n.iter){
  s<-sample(101790,30000)	
  x.a<-avail.data[s,]
  x.u<-used.data

  x.glm<-rbind(x.u, x.a)
  y<-append(rep(1, length(x.u[,1])), rep(0, length(x.a[,1])))
  out<-glm(y~x.glm[,1]+x.glm[,2]+x.glm[,3], family=binomial(link="logit"))
  
  beta.0.30[i]<-out$coeff[1]
  beta.1.30[i]<-out$coeff[2]
  beta.2.30[i]<-out$coeff[3]
  beta.3.30[i]<-out$coeff[4]
}

# 10 000 available locations, 1 000 iterations
n.iter=100
 
beta.0.10<-rep(0,n.iter)
beta.1.10<-rep(0,n.iter)
beta.2.10<-rep(0,n.iter)
beta.3.10<-rep(0,n.iter)
 
 
for(i in 1:n.iter){
  s<-sample(101790,10000)	
  x.a<-avail.data[s,]
  x.u<-used.data

  x.glm<-rbind(x.u, x.a)
  y<-append(rep(1, length(x.u[,1])), rep(0, length(x.a[,1])))
  out<-glm(y~x.glm[,1]+x.glm[,2]+x.glm[,3], family=binomial(link="logit"))
  
  beta.0.10[i]<-out$coeff[1]
  beta.1.10[i]<-out$coeff[2]
  beta.2.10[i]<-out$coeff[3]
  beta.3.10[i]<-out$coeff[4]
}

# 5000 available locations, 1 000 iterations
n.iter=100
 
beta.0.5<-rep(0,n.iter)
beta.1.5<-rep(0,n.iter)
beta.2.5<-rep(0,n.iter)
beta.3.5<-rep(0,n.iter)
 
 
for(i in 1:n.iter){
  s<-sample(101790,5000)	
  x.a<-avail.data[s,]
  x.u<-used.data

  x.glm<-rbind(x.u, x.a)
  y<-append(rep(1, length(x.u[,1])), rep(0, length(x.a[,1])))
  out<-glm(y~x.glm[,1]+x.glm[,2]+x.glm[,3], family=binomial(link="logit"))
  
  beta.0.5[i]<-out$coeff[1]
  beta.1.5[i]<-out$coeff[2]
  beta.2.5[i]<-out$coeff[3]
  beta.3.5[i]<-out$coeff[4]
}


# 100 available locations, 1 000 iterations
n.iter=100
 
beta.0.1<-rep(0,n.iter)
beta.1.1<-rep(0,n.iter)
beta.2.1<-rep(0,n.iter)
beta.3.1<-rep(0,n.iter)
 
 
for(i in 1:n.iter){
  s<-sample(101790,100)	
  x.a<-avail.data[s,]
  x.u<-used.data

  x.glm<-rbind(x.u, x.a)
  y<-append(rep(1, length(x.u[,1])), rep(0, length(x.a[,1])))
  out<-glm(y~x.glm[,1]+x.glm[,2]+x.glm[,3], family=binomial(link="logit"))
  
  beta.0.1[i]<-out$coeff[1]
  beta.1.1[i]<-out$coeff[2]
  beta.2.1[i]<-out$coeff[3]
  beta.3.1[i]<-out$coeff[4]
}

# Plot results

#Elevation

beta.1.up<-rep(0,4)
beta.1.low<-rep(0,4)
beta.1.mean<-rep(0,4)

		
beta.1.up[1]<-quantile(beta.1.30, prob=0.975, na.rm=TRUE)
beta.1.up[2]<-quantile(beta.1.10, prob=0.975, na.rm=TRUE)
beta.1.up[3]<-quantile(beta.1.5, prob=0.975, na.rm=TRUE)
beta.1.up[4]<-quantile(beta.1.1, prob=0.975, na.rm=TRUE)

beta.1.low[1]<-quantile(beta.1.30, prob=0.025, na.rm=TRUE)
beta.1.low[2]<-quantile(beta.1.10, prob=0.025, na.rm=TRUE)
beta.1.low[3]<-quantile(beta.1.5, prob=0.025, na.rm=TRUE)
beta.1.low[4]<-quantile(beta.1.1, prob=0.025, na.rm=TRUE)

beta.1.mean[1]<-mean(beta.1.30,na.rm=TRUE)
beta.1.mean[2]<-mean(beta.1.10,na.rm=TRUE)
beta.1.mean[3]<-mean(beta.1.5,na.rm=TRUE)
beta.1.mean[4]<-mean(beta.1.1,na.rm=TRUE)

Availability<-c(30000, 10000,5000, 100)

plot(Availability, beta.1.up, typ="l", xaxt="n", ylim=c(min(beta.1.low), max(beta.1.up)), lty=2, ylab="Coefficient Elevation")
 axis(side=1, at=Availability, label=Availability)
 lines(Availability, beta.1.low, lty=2)
 lines(Availability, beta.1.mean)
 

#Distance to roads

beta.2.up<-rep(0,4)
beta.2.low<-rep(0,4)
beta.2.mean<-rep(0,4)
		
beta.2.up[1]<-quantile(beta.2.30, prob=0.975, na.rm=TRUE)
beta.2.up[2]<-quantile(beta.2.10, prob=0.975, na.rm=TRUE)
beta.2.up[3]<-quantile(beta.2.5, prob=0.975, na.rm=TRUE)
beta.2.up[4]<-quantile(beta.2.1, prob=0.975, na.rm=TRUE)

beta.2.low[1]<-quantile(beta.2.30, prob=0.025, na.rm=TRUE)
beta.2.low[2]<-quantile(beta.2.10, prob=0.025, na.rm=TRUE)
beta.2.low[3]<-quantile(beta.2.5, prob=0.025, na.rm=TRUE)
beta.2.low[4]<-quantile(beta.2.1, prob=0.025, na.rm=TRUE)

beta.2.mean[1]<-mean(beta.2.30,na.rm=TRUE)
beta.2.mean[2]<-mean(beta.2.10,na.rm=TRUE)
beta.2.mean[3]<-mean(beta.2.5,na.rm=TRUE)
beta.2.mean[4]<-mean(beta.2.1,na.rm=TRUE)

Availability<-c(30000, 10000,5000, 100)

plot(Availability, beta.2.up, typ="l", xaxt="n", ylim=c(min(beta.2.low), max(beta.2.up)), lty=2, ylab="Coefficient Distance to Roads")
 axis(side=1, at=Availability, label=Availability)
 lines(Availability, beta.2.low, lty=2)
 lines(Availability, beta.2.mean)
 
 
#Slope

beta.3.up<-rep(0,4)
beta.3.low<-rep(0,4)
beta.3.mean<-rep(0,4)
		
beta.3.up[1]<-quantile(beta.3.30, prob=0.975, na.rm=TRUE)
beta.3.up[2]<-quantile(beta.3.10, prob=0.975, na.rm=TRUE)
beta.3.up[3]<-quantile(beta.3.5, prob=0.975, na.rm=TRUE)
beta.3.up[4]<-quantile(beta.3.1, prob=0.975, na.rm=TRUE)

beta.3.low[1]<-quantile(beta.3.30, prob=0.025, na.rm=TRUE)
beta.3.low[2]<-quantile(beta.3.10, prob=0.025, na.rm=TRUE)
beta.3.low[3]<-quantile(beta.3.5, prob=0.025, na.rm=TRUE)
beta.3.low[4]<-quantile(beta.3.1, prob=0.025, na.rm=TRUE)


beta.3.mean[1]<-mean(beta.3.30,na.rm=TRUE)
beta.3.mean[2]<-mean(beta.3.10,na.rm=TRUE)
beta.3.mean[3]<-mean(beta.3.5,na.rm=TRUE)
beta.3.mean[4]<-mean(beta.3.1,na.rm=TRUE)


Availability<-c(30000, 10000,5000, 100)

plot(Availability, beta.3.up, typ="l", xaxt="n", ylim=c(min(beta.3.low), max(beta.3.up)), lty=2, ylab="Coefficient Slope")
 axis(side=1, at=Availability, label=Availability)
 lines(Availability, beta.3.low, lty=2)
 lines(Availability, beta.3.mean)