# Code used in simulations for Northrup et al. 

# 1 Simple simulation on a true landscape with matched and mismatched availability samples
# Requires elev_simple.asc file included

# Load needed libraries

library(raster)
library(arm)

# Load elevation raster and create polygon within which to simulate

elev<-raster("~r_rasters\\elev_simple.ASC")

coord<-matrix(0,5,2)

coord[1,]<-c(0,0)
coord[2,]<-c(330,0)
coord[3,]<-c(330,330)
coord[4,]<-c(0,330)
coord[5,]<-c(0,0)

poly<-Polygon(coord)

x.bar=cellStats(elev, "mean")
x.std=cellStats(elev, "sd")

# Random draw of number of points

lam.max=2

a=108900

N<-rpois(1, lam.max*a)

# Simualte N random points

# For matched use and availability

pts<-spsample(poly, N, "random")

# For mistmatched use and availability

# coord.2<-matrix(0,5,2)

# coord.2[1,]<-c(200,100)
# coord.2[2,]<-c(300,100)
# coord.2[3,]<-c(300,200)
# coord.2[4,]<-c(200,200)
# coord.2[5,]<-c(200,100)

# poly.2<-Polygon(coord.2)

# pts<-spsample(poly.2, N, "random")

# Extract values

x.extract<-extract(elev, pts)

# Scale values and create design matrix

x.scale<-(x.extract-x.bar)/x.std

x.mat<-cbind(rep(1,length(x.scale)),x.scale)

# Vector of betas- Note first value is intercept, and can be used to alter the number of locations

# beta<-c(-2,2)	#mismatch
beta<-c(10,2)	#match

# Calculate lambda at each point and convert to probability

lam=exp(x.mat%*%beta)

max(lam)  # check to make sure this is less than lam.max

p=lam/lam.max

# Draw 1,000,000 random locations- same area for matched or mismatched sample: Note this step can take some time

pts.a<-spsample(poly, 1000000, "random")

# Extract values

x.extract.a<-extract(elev, pts.a)

# Scale values and create design matrix

x.scale.a<-(x.extract.a-x.bar)/x.std

x.mat.a<-cbind(rep(1,length(x.scale.a)),x.scale.a)

# Fit RSFs- to reproduce curves in manuscript, rerun simulation for multiple values of pts.a

iter=500	#controls number of RSFs to fit

pts.a=10000	#controls number of available locations to draw for each iteration

# Create vectors to store results

beta.0<-rep(0,iter)
beta.1<-rep(0,iter)

# Run simulation

for(i in 1:iter){
	dec<-rbinom(N, 1, p)
	x.u<-x.mat[dec==1,]
	x.a<-x.mat.a[sample(N, pts.a, replace=T),]
		
	y<-append(rep(1,length(x.u[,1])), rep(0, length(x.a[,1])))
	x<-rbind(x.u, x.a)
	model<-glm(y~x[,2], family=binomial(link="logit"))
	beta.0[i]<-model$coeff[1]
	beta.1[i]<-model$coeff[2]
}

# Calculate expectation and simulation envelope

expec<-mean(beta.1)
sim.env.low<-quantile(beta.1, 0.025)
sim.env.up<-quantile(beta.1, 0.975)