# Code used in simulations for Northrup et al. 

# 3 Simulation of autocorrelated covariates and fitting RSFs

# Load needed libraries
library(geoR)
library(arm)
library(raster)

# Simulate Gaussian random field

phi=100

x<-grf(100, grid="reg", nx=100, ny=100, xlims=c(0,100), ylims=c(0,100), cov.pars=c(1,phi))

# Random draw of number of points

lam.max=10

a=10000		#area of "study area"

N<-rpois(1, lam.max*a)

# Simulate location of points

p.coord<-rbind(c(100,0),c(0,0),c(0,100),c(100,100), c(100,0))

poly<-Polygon(p.coord)

# For matched use and availability

pts<-spsample(poly,N,"random")

# For mismatched use and availability

# p.coord.2<-rbind(c(75,75),c(25,75),c(25,25),c(75,25), c(75,75))

# poly.2<-Polygon(p.coord.2)

# pts<-spsample(poly.2,N,"random")

# Extract X values

x.extract<-extract(raster(x), pts)

# Scale values and combine into a design matrix
x.bar<-mean(x$data)
x.std<-sd(x$data)

x.scale<-(x.extract-x.bar)/x.std
x.mat<-cbind(rep(1,length(x.scale)), x.scale)

# Vector of betas- Note first value is intercept, and can be used to alter the number of locations

beta<-c(-3,.5)

# Calculate lambda at each point and convert to probability

lam<-exp(x.mat%*%beta)

max(lam)  # check to make sure this is less than lam.max

p<-lam/lam.max

# Draw 1,000,000 random locations- same area for matched or mismatched sample

pts.a<-spsample(poly,1000000,"random")

# Extract X values

x.extract.a<-extract(raster(x), pts.a)

# Scale values and combine into a design matrix

x.scale.a<-(x.extract.a-x.bar)/x.std
x.mat.a<-cbind(rep(0,length(x.scale.a)), x.scale.a)

# Fit RSFs- to reproduce curves in manuscript, rerun simulation for multiple values of pts.a

iter=500	#controls number of RSFs to fit

pts.a=1000	#controls number of available locations to draw for each iteration

# Create vectors to store results

beta.0<-rep(0,iter)
beta.1<-rep(0,iter)

# Run simulation

for(i in 1:iter){
	dec<-rbinom(N, 1, p)
	x.u<-x.mat[dec==1,]
	x.a<-x.mat.a[sample(1000000,pts.a, replace=T),]
	
	y<-append(rep(1,length(x.u[,1])), rep(0, length(x.a[,1])))
	x<-rbind(x.u, x.a)
	model<-glm(y~x[,2], family=binomial(link="logit"))
	beta.0[i]<-model$coeff[1]
	beta.1[i]<-model$coeff[2]
}

# Calculate expectation and simulation envelope

expec<-mean(beta.1)
sim.env.low<-quantile(beta.1, 0.025)
sim.env.up<-quantile(beta.1, 0.975)


